from fastapi import FastAPI
from pathlib import Path

from app.api.v1.api import api_router
from app.core.config import settings
from app.db.session import create_db_and_tables

app = FastAPI(
    title=settings.PROJECT_NAME,
    openapi_url=f"{settings.API_V1_STR}/openapi.json",
)

app.include_router(api_router, prefix=settings.API_V1_STR)


@app.get("/health", tags=["health"])
async def health():
    return {
        "status": "ok",
        "name": settings.PROJECT_NAME,
        "version": settings.VERSION,
    }


@app.on_event("startup")
def on_startup():
    create_db_and_tables()


if __name__ == "__main__":
    import uvicorn

    uvicorn.run("main:app", host="0.0.0.0", port=8000, reload=True)